The function fit_copula_model_BinCont() fits the copula model for a
continuous surrogate endpoint and binary true endpoint. Because the bivariate
distributions of the surrogate-true endpoint pairs are functionally
independent across treatment groups, a bivariate distribution is fitted in
each treatment group separately.
fit_copula_model_BinCont(
data,
copula_family,
marginal_surrogate,
marginal_surrogate_estimator = NULL,
twostep = FALSE,
fitted_model = NULL,
maxit = 500,
method = "BFGS"
)WIP
A data frame in the correct format (See details).
One of the following parametric copula families:
"clayton", "frank", "gaussian", or "gumbel".
Marginal distribution for the surrogate. For all
available options, see ?Surrogate::cdf_fun.
Not yet implemented
(boolean) if TRUE, the two step estimator implemented in
twostep_BinCont() is used for estimation.
Fitted model from which initial values are extracted. If
NULL (default), standard initial values are used. This option intended
for when a model is repeatedly fitted, e.g., in a bootstrap.
Maximum number of iterations for the numeric optimization, defaults to 500.
Optimization algorithm for maximizing the objective function.
For all options, see ?maxLik::maxLik. Defaults to "BFGRS".